breed[rainfalls rainfall]
breed[stations station]
breed[subcatchments subcatchment]

rainfalls-own
[
  cumulative-intensity
  distance-from-cores
  intensity
  sampled-cumulative-intensity
]

stations-own
[
  station-maximum-distance
  station-rainfall
  station-samples-data
  station-samples-distance
  station-samples-distance-group
  station-samples-rainfall
  station-samples-square-difference
  station-samples-xy
]

subcatchments-own
[
  subcatchment-id
]

globals
[
  all-samples-data
  all-samples-distance-group
  all-samples-number-group    
  all-samples-semivariance
  all-samples-square-difference-group
  all-samples-sum-square-difference-group
  F_-list
  F_-pot
  f-limit-comparison
  f-limit-comparison-pot
  f-limit-list
  f-list
  f-observation
  f-simulation
  repeat-header
  incompatibility-list
  julian-date
  landscape-annual-rainfall
  max-rainfall-list
  max-x-subcatchment
  max-y-subcatchment
  min-rainfall-list
  min-x-subcatchment
  min-y-subcatchment
  month
  output-file-name-for-GenRiver
  overall-rainfall-data-list
  p-list
  rain-days
  rainfall-data-file-name
  rainfall-data-list
  scaling-area
  scaling-average-rainfall
  scaling-maximum-rainfall
  setup-done-code
  simulated-F
  simulated-storms-intensity
  simulated-storms-number
  simulation-time
  spatial-rainfall-samples-list
  station-list
  station-rainfall-list
  storm-event-probability-list
  storm-intensity-pot
  storms-number-list
  subcatchment-daily-rainfall-data
  subcatchment-id-list
  subcatchment-xyz-file-name
  subcatchment-xyz-data
  wet-cells-fraction-list
  wet-days-fraction-list
]

to setup
  ca
  initialize
  set simulation-time 0
  set station-rainfall-list[]
  if (do-spatial-analyses?)
  [
    define-semivariance-samples
    set rain-days 0
  ]
  set setup-done-code 1
end

;to simulate daily rainfall for defined simulation duration (years)
to go
  ifelse (setup-done-code = 1)
  [
    ifelse simulation-time < simulation-duration
    [
      if (report-for-GenRiver?)
      [
        file-open output-file-name-for-GenRiver
        file-print repeat-header
        file-close
      ]
      ifelse sum incompatibility-list <= 0
      [
        simulate        
        set landscape-annual-rainfall mean values-from rainfalls [cumulative-intensity]
        plot-annual-rainfall
        if (report-for-GenRiver?)
        [
          file-open output-file-name-for-GenRiver
          file-print ""
          file-print ""
          file-close
        ]
        set simulation-time simulation-time + 1
      ]
      [
        user-message "[SpatRain] You can not simulate using incompatible storm properties. Please, modify your assumption."
        stop
      ]
    ]
    [
      user-message "[SpatRain] Finished. You must setup the model again to run other simulations."
      if (report-for-GenRiver?)
      [
        file-open output-file-name-for-GenRiver
        file-print ""
        file-print ""
        file-close
      ]
      stop
    ]
  ]
  [
    user-message "[SpatRain] You have not setup the model.  You must setup the model first."
    stop
  ]
end

;;to simulate daily rainfall
to simulate
  set julian-date 1
  
  ask rainfalls
  [
    set cumulative-intensity 0
    set sampled-cumulative-intensity 0
  ]
  
  while [julian-date <= 365]
  [
    no-display
    set month position true (map [julian-date >= ?1 and julian-date <= ?2] [1	32	60	91	121	152	182	213	244	274	305	335] [31	59	90	120	151	181	212	243	273	304	334	365])
    ifelse random-float 1.00 < item month storm-event-probability-list
    [
      let this-month-F-pot item month F_-pot
      let previous-months-F-pot sublist F_-pot 0 month
      let next-months-F-pot sublist F_-pot (month + 1) 12
      
      set simulated-storms-number item month storms-number-list
      set simulated-F one-of shuffle this-month-F-pot
      
      ;;take out picked number from the pot
      set F_-pot sentence previous-months-F-pot fput (remove-item (position simulated-F this-month-F-pot) this-month-F-pot) next-months-F-pot
      
      set simulated-storms-intensity one-of shuffle (item simulated-F (item month storm-intensity-pot))
    ]
    [
      set simulated-storms-number 0
      set simulated-storms-intensity 0
    ]
    generate-storms simulated-storms-number
    distribute-storms simulated-storms-intensity
    
    ask rainfalls
    [
      set cumulative-intensity cumulative-intensity + intensity
    ]  
    
    without-interruption
    [
      ask stations
      [    
        set station-rainfall item 0 values-from rainfalls-here [intensity]
      ]
    ]
    
    set station-rainfall-list sort(sentence (values-from stations [station-rainfall]) station-rainfall-list)
    
    without-interruption
    [
      let list1[]
      foreach subcatchment-id-list
      [
        let list2[]
        ask subcatchments with[subcatchment-id = ?]
        [
          set list2 lput (item 0 values-from rainfalls-here[intensity]) list2
        ]
        set list1 lput list2 list1
      ]
      set subcatchment-daily-rainfall-data 
        (map[precision (mean ?) 0] list1)
    ]
    
    ;;report for GenRiver here
    if (report-for-GenRiver?)
    [
      report-for-GenRiver
    ] 
    
    if (do-spatial-analyses?)
    [
      if rain-days < sampling-day
      [
        if simulated-storms-number > 0
        [
          ask rainfalls
          [
            set sampled-cumulative-intensity sampled-cumulative-intensity + intensity
          ]
          calculate-semivariance
          calculate-scaling-rules
          plot-semivariance
          plot-maximum-rainfall-scale
          plot-average-rainfall-scale
          set rain-days rain-days + 1
        ]
      ]
    ]     
    plot-daily-rainfall
    plot-rainfall-data-distribution
    display
    set julian-date julian-date + 1
  ]
end

;;read xyz data
to-report read-xyz-data[xyz-file]
  let data[]
  if (xyz-file != false)
  [
    file-open xyz-file
    while [ not file-at-end? ]
    [ 
      set data sentence data (list (list file-read file-read file-read))
    ]
    file-close
  ]
  report data
end

;;function to read rainfall data
to read-rainfall-data[rainfall-data-file]
  let rainfall-data []
  if (rainfall-data-file != false)
  [
    file-open rainfall-data-file
    while [ not file-at-end? ]
    [ 
      set rainfall-data sentence rainfall-data file-read
    ]
    file-close
  ]
  
  let series-number length (rainfall-data) / 365
  
  set overall-rainfall-data-list sort rainfall-data
    
  set rainfall-data-list
    (
    list
    sort sublist map [precision ? 0] rainfall-data 0 (series-number * 31)
    sort sublist map [precision ? 0] rainfall-data (series-number * 31) (series-number * (31 + 28))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28)) (series-number * (31 + 28 + 31))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31)) (series-number * (31 + 28 + 31 + 30))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30)) (series-number * (31 + 28 + 31 + 30 + 31))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31)) (series-number * (31 + 28 + 31 + 30 + 31 + 30))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30 + 31))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30 + 31)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30 + 31 + 30))
    sort sublist map [precision ? 0] rainfall-data (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30 + 31 + 30)) (series-number * (31 + 28 + 31 + 30 + 31 + 30 + 31 + 31 + 30 + 31 + 30 + 31))
  )
end

;;create stations
to create-stations
  ;;station
  set-default-shape stations "triangle"
  create-custom-stations sampled-patch-number
  [
    setxy random max-pxcor random max-pycor
    set color red
  ]
  set station-list values-from stations [who]
end

to create-subcatchments
  foreach subcatchment-xyz-data
  [
    create-custom-subcatchments 1
    [
      setxy ((first ? / 1000) - min-x-subcatchment + buffer)  ((item 1 ? / 1000) - min-y-subcatchment + buffer)
      set subcatchment-id last ?
      ht
    ]
  ]  
  ask subcatchments with[subcatchment-id = missing-value]
  [
    die
  ]
  ask subcatchments
  [
    set pcolor-of patch-here grey
  ]
  
  set subcatchment-id-list sort (remove-duplicates (values-from subcatchments[subcatchment-id]))
end

to customize-coordinate
  let x-subcatchment-list[]
  let y-subcatchment-list[]
  foreach subcatchment-xyz-data
  [
    set x-subcatchment-list lput (first ? / 1000) x-subcatchment-list
    set y-subcatchment-list lput (item 1 ? / 1000) y-subcatchment-list
  ]  
  set min-x-subcatchment min x-subcatchment-list
  set min-y-subcatchment min y-subcatchment-list
  set max-x-subcatchment max x-subcatchment-list
  set max-y-subcatchment max y-subcatchment-list  
end

;;initialization
to initialize
  no-display
  set storm-core-length max list storm-core-length storm-core-width
  open-rainfall-timeseries
  open-subcatchment-map
  
  set subcatchment-xyz-data read-xyz-data subcatchment-xyz-file-name
  customize-coordinate
  
  ifelse ((max-x-subcatchment - min-x-subcatchment + 2 * buffer) <= max-pxcor or (max-y-subcatchment - min-y-subcatchment + 2 * buffer) <= max-pycor)
  [
    create-subcatchments
    create-stations
    
    if (report-for-GenRiver?)
    [
      ask-output-file-for-GenRiver
      make-output-file-header-for-GenRiver
    ]
    
    ;;initialize spatial rain
    set-default-shape rainfalls "square"
    ask patches
    [
      sprout-rainfalls 1 
      [
        set color white
      ]
    ]
  
    ;;check incompatibility
    read-rainfall-data rainfall-data-file-name
    
    ;;xxx
    set min-rainfall-list map [ifelse-value (length remove 0 ? > 0) [min remove 0 ?] [0]] rainfall-data-list
    ;;xxx
    set max-rainfall-list map [ifelse-value (length remove 0 ? > 0) [max remove 0 ?] [0]] rainfall-data-list
    set f-limit-list (map [define-interval-limit class-number ?1 ?2] min-rainfall-list max-rainfall-list)
    ;;xxx
    set f-list (map [calculate-exceedance-probability ?1 ?2] (map [ifelse-value (length remove 0 ? > 0) [remove 0 ?] [?]] rainfall-data-list) f-limit-list)
    set wet-cells-fraction-list (map [calculate-wet-cells-fraction ?1 ?2] min-rainfall-list max-rainfall-list)  
    set wet-days-fraction-list map [calculate-wet-days-fraction ?] rainfall-data-list
    set storms-number-list (map [calculate-storms-number ?1 ?2] wet-cells-fraction-list wet-days-fraction-list)
    set spatial-rainfall-samples-list (map [sample-spatial-rainfall ?1 ?2 replicate] storms-number-list max-rainfall-list) ;((map [one-of shuffle ?] (map [remove 0 ?] rainfall-data-list)))
    set p-list (map [calculate-exceedance-probability ?1 ?2] (map [remove 0 ?] spatial-rainfall-samples-list) f-limit-list)  
    set F_-list (map [calculate-F ?1 ?2] f-list p-list)
    set incompatibility-list map [check-incompatibility ?] F_-list
    if sum incompatibility-list = 0
    [
      set storm-event-probability-list (map [calculate-storm-event-probability ?1 ?2] (map [ifelse-value (length ? > 0) [(ifelse-value (length remove 0 ? > 0) [length remove 0 ?] [0]) / length ?] [0]] spatial-rainfall-samples-list) wet-days-fraction-list)
      set F_-pot map [generate-F-pot ?] F_-list
      ;;xxx
      set storm-intensity-pot (map [generate-storm-intensity-pot ?1 ?2] (map [remove 0 ?] rainfall-data-list) f-limit-list)
    ]
     
    ;;report incompatibility
    user-message 
      "[SpatRain] Number of incompatible classes: " 
      + " [Jan] " + item 0 incompatibility-list 
      + " [Feb] " + item 1 incompatibility-list
      + " [Mar] " + item 2 incompatibility-list
      + " [Apr] " + item 3 incompatibility-list
      + " [May] " + item 4 incompatibility-list
      + " [Jun] " + item 5 incompatibility-list
      + " [Jul] " + item 6 incompatibility-list
      + " [Aug] " + item 7 incompatibility-list
      + " [Sep] " + item 8 incompatibility-list
      + " [Oct] " + item 9 incompatibility-list
      + " [Nov] " + item 10 incompatibility-list
      + " [Dec] " + item 11 incompatibility-list  
    
    display  
    ask rainfalls
    [
      set color white
    ]
  ]
  [
    user-message "[SpatRain] Please, adjust your view by pressing 'Edit...' button on top of it, so its max-pxcor >= " 
    + (max-x-subcatchment - min-x-subcatchment + 2 * buffer) + " and its max-pycor >= " 
    + (max-y-subcatchment - min-y-subcatchment + 2 * buffer) + ".  Adjust the pixel size to the new setting accordingly!"
    stop
  ]
end

;;function to generate number of storms
to generate-storms[storms-number]
  let cores-xy[]
  repeat storms-number
  [
    let x-start random-pxcor
    let y-start random-pycor  
    let angle random 360
    let step 0
    set cores-xy fput list x-start y-start cores-xy
    repeat round (1 + (storm-core-length - storm-core-width))
    [
      let x-core x-start + (step * cos angle)
      let y-core y-start + (step * sin angle)
      set cores-xy fput (list x-core y-core) cores-xy
      set step step + 1
    ]
  ]  
  ask rainfalls
  [
    set distance-from-cores 10 ^ 31
  ]
  without-interruption
  [
    ask rainfalls at-points cores-xy
    [
      let core who
      ask rainfalls
      [
        set distance-from-cores 
        min list 
        distance-from-cores
        (max list 0
        (distance rainfall core - (0.5 * storm-core-width)))
      ]
    ]
  ]
end

;;function to distribute rainfall intensity from storms' cores
to distribute-storms[cores-intensity]
  ask rainfalls
  [
    set intensity precision
    max list 0(
    cores-intensity *
    (1 - exp (-((storm-spread / 
    (max list 0.001 (distance-from-cores))) 
    ^ storm-edge)))) 0
    set color scale-color blue intensity 100 0
  ]
end

;;function to define interval limit used to calculate exceedance probability
to-report define-interval-limit[interval-number min-limit max-limit]
  let i 0
  let limit[]
  repeat interval-number
  [
    ;;xxx
    set limit lput (ifelse-value (max-limit > 0) [(precision((((e ^ (ln (min-limit / max-limit) / interval-number))) ^ i) * max-limit)0)] [0]) limit
    set i i + 1
  ]
  set limit lput min-limit limit
  report limit
end

;;function to calculate exceedance probability
to-report calculate-exceedance-probability[data limit]
  let n ((length limit) - 1)
  let p[]
  set p lput (ifelse-value (length data > 0) [length (filter [? <= item 0 limit and ? >= item 1 limit] data) / length data] [0]) p
  let i 1
  repeat n - 1
  [
    set p lput (ifelse-value (length data > 0) [length (filter [? < item i limit and ? >= item (i + 1) limit] data) / length data] [0]) p
    set i i + 1
  ]  
  let cum-p[]
  let cum 0
  let j 0
  repeat n
  [
    let val cum + (item j p)
    set cum-p lput val cum-p
    set cum val
    set j j + 1  
  ]
  report cum-p
end

;;function to calculate probability of rainfall intensity at storms' cores
to-report calculate-F[f p]
  let cum-F (map [ifelse-value (?2 > 0) [?1 / ?2] [0]] f p)
  let F_ lput item 0 cum-F []
  let i 1
  repeat (length f) - 1
  [
    set F_ lput ((item i cum-F) - (item (i - 1) cum-F)) F_
    set i i + 1
  ]
  report F_
end

;;function to generate pot of F
to-report generate-F-pot[F]
  let i 0
  let F-pot[]
  repeat (length F)
  [
    set F-pot sentence (n-values ((item i F) * 100 * simulation-duration) [i]) F-pot
    set i i + 1
  ]
  report F-pot
end

;;function to generate pot of storm intensity
to-report generate-storm-intensity-pot[data limit]
  let n ((length limit) - 1)
  let cores-intensity[]
  set cores-intensity lput (filter [? <= item 0 limit and ? >= item 1 limit] data) cores-intensity
  let i 1
  repeat n - 1
  [
    set cores-intensity lput (filter [? < item i limit and ? >= item (i + 1) limit] data) cores-intensity
    set i i + 1
  ]
  report cores-intensity
end

;;group data
to-report group-data[data limit]
  let n ((length limit) - 1)
  let grouped-data[]
  set grouped-data lput (filter [? <= item 0 limit and ? >= item 1 limit] data) grouped-data
  let i 1
  repeat n - 1
  [
    set grouped-data lput (filter [? < item i limit and ? >= item (i + 1) limit] data) grouped-data
    set i i + 1
  ]
  report grouped-data
end

;;function to identify incompatibility
to-report check-incompatibility[F]
  report length (filter [? < 0] F)
end

;;function to calculate wet cells fraction
to-report calculate-wet-cells-fraction[min-intensity max-intensity]
  let z ifelse-value (max-intensity > 0) [min-intensity / max-intensity] [0]
  ;;xxx
  let j ifelse-value (z > 0) [storm-spread / (e ^ (ln(- ln(1 - z)) / storm-edge))] [0]
  let r1 (0.5 * storm-core-width) + j
  let r2 (0.5 * storm-core-length) + j
  let a1 pi * r1 * r2
  let a2 count patches
  report min list 1 (a1 / a2)
end

;;function to calculate wet days fraction
to-report calculate-wet-days-fraction[data]
  report ifelse-value (length data > 0) [(length (remove 0 data)) / (length data)] [0]
end

;;function to calculate number of storms
to-report calculate-storms-number[c d]
  report ifelse-value (c = 1) [1] [round (ln(1 - d) / ln (1 - c))]
end

;;function to calculate probability of storm events
to-report calculate-storm-event-probability[c d]
  report ifelse-value (c = 0) [0] [min list 1 (d / c)]
end

;;sample spatial rainfall to calculate p
to-report sample-spatial-rainfall[storms-number storms-cores-intensity sampling-replicate]
  let samples[]
  repeat sampling-replicate
  [
    generate-storms storms-number
    distribute-storms storms-cores-intensity
    set samples sentence (values-from rainfalls [intensity]) samples
  ]
  report samples
end

;;function to define sampled points for semivariance analysis
to define-semivariance-samples
  ask stations 
  [
    set station-maximum-distance 10 ^ (- 31)
    set station-samples-xy[]
  ]
  ask stations
  [
    let station-id who
    ask rainfalls
    [
      set station-maximum-distance-of station station-id max list station-maximum-distance-of station station-id (distance station station-id)
    ]
  ]
  repeat replicate
  [
    without-interruption
    [
      ask stations
      [
        let step sampling-distance
        let station-id who
        let angle random 360
        ask rainfalls
        [
          if step < station-maximum-distance-of station station-id
          [
            let x-sample precision (xcor-of station station-id + (step * cos angle)) 0
            let y-sample precision (ycor-of station station-id + (step * sin angle)) 0
          
            if (x-sample >= min-pxcor and x-sample <= max-pxcor) and (y-sample >= min-pycor and y-sample <= max-pycor)
            [
              set station-samples-xy-of station station-id remove-duplicates (fput (list x-sample y-sample) station-samples-xy-of station station-id)
            ]
            set step step + sampling-distance
          ] 
        ]
      ]
    ]
  ]
  ask stations
  [
    set station-samples-distance map [precision (distancexy item 0 ? item 1 ?) 0] station-samples-xy
    set station-samples-distance-group remove-duplicates station-samples-distance
  ]
  set all-samples-distance-group sort remove-duplicates reduce [sentence ?1 ?2] (values-from stations [station-samples-distance-group])
  set all-samples-data[]
end

;;procedure to calculate semivariance
to calculate-semivariance
  foreach station-list
  [
    set station-samples-rainfall-of station ? values-from rainfalls at-points (station-samples-xy-of station ?) [intensity]
  ]
  
  ask stations
  [
    set station-samples-square-difference (map [(station-rainfall - ?) ^ 2] station-samples-rainfall)
    set station-samples-data (map[list ?1 ?2] station-samples-distance station-samples-square-difference)
  ]
  
  set all-samples-data sentence (reduce [sentence ?1 ?2] (values-from stations [station-samples-data])) all-samples-data
  
  let n (length all-samples-distance-group)
  let i 0
  set all-samples-square-difference-group[]
  repeat n
  [
    set all-samples-square-difference-group lput (reduce[sentence ?1 ?2](map[remove-item 0 ?] (filter [item 0 ? = item i all-samples-distance-group] all-samples-data))) all-samples-square-difference-group
    set i i + 1
  ]
  
  set all-samples-sum-square-difference-group map[sum ?] all-samples-square-difference-group  
  set all-samples-number-group map[length ?] all-samples-square-difference-group
  set all-samples-semivariance (map[?1 / (2 * ?2)] all-samples-sum-square-difference-group all-samples-number-group)
end

;;function to sample rainfalls by area scale
to calculate-scaling-rules
  let n 0 
  set scaling-area[]
  set scaling-maximum-rainfall[]
  set scaling-average-rainfall[]
  repeat (replicate * 20)
  [
    let x-start random-pxcor
    let y-start random-pycor  
    let angle random 360
    let step 0
    let radius max list 1 random max list max-pxcor max-pycor
    set scaling-area fput (count rainfalls with [distancexy x-start y-start <= radius]) scaling-area
    set scaling-maximum-rainfall fput (max values-from rainfalls with [distancexy x-start y-start <= radius] [sampled-cumulative-intensity]) scaling-maximum-rainfall
    set scaling-average-rainfall fput (mean values-from rainfalls with [distancexy x-start y-start <= radius] [sampled-cumulative-intensity]) scaling-average-rainfall
    set n n + 1
  ]
end

;;plot outputs: point daily rainfall
to plot-daily-rainfall
  set-current-plot "Patch Rainfall"
  set-current-plot-pen "Simulated"
  foreach station-list
  [
    plotxy julian-date station-rainfall-of station ?
  ]
end

;;plot outputs: semivariogram
to plot-semivariance
  set-current-plot "Semivariogram"
  clear-plot
  foreach n-values length all-samples-distance-group [?]
  [
    plotxy item ? all-samples-distance-group item ? all-samples-semivariance
  ]
end

;;plot outputs: maximum rainfall scale
to plot-maximum-rainfall-scale
  set-current-plot "Rmax vs Area"
  clear-plot
  foreach n-values length scaling-area [?]
  [
    plotxy item ? scaling-area item ? scaling-maximum-rainfall
  ]
end

;;plot outputs: averages rainfall scale
to plot-average-rainfall-scale
  set-current-plot "Rmean vs Area"
  clear-plot
  foreach n-values length scaling-area [?]
  [
    plotxy item ? scaling-area item ? scaling-average-rainfall
  ]
end


;;plot outputs: mean annual rainfall
to plot-annual-rainfall
  set-current-plot "Landscape Rainfall"
  set-current-plot-pen "Simulated"
  plotxy simulation-time landscape-annual-rainfall
end

;;plot outputs: exceedance probability
to plot-rainfall-data-distribution
  set f-limit-comparison define-interval-limit class-number min (sentence (remove 0 ( map [precision ? 0] station-rainfall-list)) (remove 0 (map [precision ? 0] overall-rainfall-data-list))) max (sentence (remove 0 (map [precision ? 0] station-rainfall-list)) (remove 0 (map [precision ? 0] overall-rainfall-data-list)))
  set f-simulation calculate-exceedance-probability remove 0 station-rainfall-list f-limit-comparison
  set f-observation calculate-exceedance-probability remove 0 overall-rainfall-data-list f-limit-comparison
  set f-limit-comparison-pot (group-data (sentence remove 0 map [precision ? 0] station-rainfall-list remove 0 map [precision ? 0] overall-rainfall-data-list) f-limit-comparison)
  
  let class-list n-values class-number [?]
  
  set-current-plot "Data Distribution"
  clear-plot
  
  set-current-plot-pen "Simulated"
  foreach class-list
  [
    if not empty? (item ? f-limit-comparison-pot)
    [
      plotxy (median (item ? f-limit-comparison-pot)) (item ? f-simulation)
    ]
  ]

  set-current-plot-pen "Observed"
  foreach class-list
  [
    if not empty? (item ? f-limit-comparison-pot)
    [
      plotxy (median (item ? f-limit-comparison-pot)) (item ? f-observation)
    ]
  ]
end

to open-rainfall-timeseries
  user-message "[SpatRain] Please, select file name of daily rainfall timeseries after this dialog! (*.tss)"
  set rainfall-data-file-name user-file
end

to open-subcatchment-map
  user-message "[SpatRain] Please, select file name of subcatchment map in xyz format after this dialog! (*.xyz)"
  set subcatchment-xyz-file-name user-file
end

to ask-output-file-for-GenRiver
    set output-file-name-for-GenRiver user-input "[SpatRain] Please, type the name of output file to save the simulation results at subcatchment level for GenRiver!" + ".out"
end

to report-for-GenRiver
  let result ""  
  foreach n-values ((length subcatchment-id-list) - 1)[?]
  [
    set result result + (item ? subcatchment-daily-rainfall-data) + "\t"
  ]
  set result result + (item ((length subcatchment-id-list) - 1) subcatchment-daily-rainfall-data)
  set result (simulation-time + 1) + "\t" + (month + 1) + "\t" + julian-date + "\t" + result
  file-open output-file-name-for-GenRiver
  file-print result
  file-close
end

to make-output-file-header-for-GenRiver
  let header ""
  foreach (bl subcatchment-id-list)
  [
    set header header + "rain[sub" + ? + "]" + "\t"
  ]
  set header header + "rain[sub" + (last subcatchment-id-list) + "]"
  set header "year" + "\t" + "month" + "\t" + "day" + "\t" + header
  set repeat-header header
  file-open output-file-name-for-GenRiver
  file-print "[SpatRain]"
  file-print ""
  file-print "Simulation results at subcatchment level on " + date-and-time + " as the input for GenRiver"
  file-print ""
  file-print "Main setting:"
  file-print "[.] Input rainfall timeseries data: " + rainfall-data-file-name
  file-print "[.] Subcatchment map: " + subcatchment-xyz-file-name
  file-print "[.] Storm spread: " + storm-spread
  file-print "[.] Storm edge: " + storm-edge
  file-print "[.] Storm core width: " + storm-core-width
  file-print "[.] Storm core length: " + storm-core-length
  file-print ""
  file-print ""
  file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
191
10
391
222
-1
-1
4.0
1
10
1
1
1
0
0
0
1
0
45
0
43

CC-WINDOW
5
583
992
678
Command Center
0

BUTTON
409
12
472
45
NIL
setup
NIL
1
T
OBSERVER
T
NIL

SLIDER
5
10
177
43
storm-spread
storm-spread
1
1000
100
1
1
NIL

SLIDER
5
49
177
82
storm-edge
storm-edge
1
500
1
1
1
NIL

SLIDER
5
88
177
121
storm-core-width
storm-core-width
1
100
7
1
1
NIL

SLIDER
5
128
177
161
storm-core-length
storm-core-length
1
100
7
1
1
NIL

BUTTON
410
57
473
90
NIL
go
T
1
T
OBSERVER
T
NIL

SLIDER
6
175
178
208
class-number
class-number
5
20
10
1
1
NIL

SLIDER
5
216
177
249
replicate
replicate
1
50
10
1
1
NIL

SLIDER
6
447
178
480
simulation-duration
simulation-duration
1
50
10
1
1
years

MONITOR
211
384
261
433
DD
julian-date
3
1

MONITOR
264
384
314
433
MM
month + 1
3
1

MONITOR
317
384
367
433
YY
simulation-time + 1
3
1

PLOT
483
10
732
187
Patch Rainfall
day
rainfall (mm)
0.0
10.0
0.0
10.0
true
true
PENS
"Simulated" 1.0 2 -13345367 true

PLOT
483
190
732
378
Data Distribution
rainfall (mm)
exceedance
0.0
5.0
0.0
1.0
true
true
PENS
"Simulated" 1.0 0 -13345367 true
"Observed" 1.0 0 -2674135 true

PLOT
735
11
983
187
Landscape Rainfall
year
rainfall (mm)
0.0
10.0
0.0
10.0
true
true
PENS
"Simulated" 1.0 1 -13345367 true

SLIDER
6
348
178
381
sampling-distance
sampling-distance
0.5
10
0.5
0.5
1
NIL

PLOT
735
190
982
378
Semivariogram
distance (km)
semivariance
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 2 -16777216 true

SLIDER
6
389
178
422
sampling-day
sampling-day
1
365
30
1
1
rain-days

PLOT
484
381
731
569
Rmax vs Area
area (km2)
rainfall (mm)
0.0
10.0
0.0
10.0
true
false
PENS
"Default" 1.0 2 -16777216 true

PLOT
735
380
982
569
Rmean vs Area
area (km2)
rainfall (mm)
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 2 -16777216 true

SWITCH
6
308
178
341
do-spatial-analyses?
do-spatial-analyses?
1
1
-1000

SLIDER
6
254
178
287
sampled-patch-number
sampled-patch-number
10
100
10
1
1
NIL

SLIDER
190
226
386
259
buffer
buffer
5
20
5
1
1
pixels

SWITCH
6
495
179
528
report-for-GenRiver?
report-for-GenRiver?
0
1
-1000

MONITOR
211
314
368
363
max storm core number
max storms-number-list
3
1

SLIDER
189
265
386
298
missing-value
missing-value
-9999
-1111
-9999
1
1
NIL

@#$#@#$#@
WHAT IS IT?
-----------
Variations in river flow tend to decrease with increasing area of consideration, partly due to a decrease in temporal correlation of rainfall events across space. Patchiness of rainfall can contribute to an increase of yield stability over space. Existing rainfall simulators tend to focus on station-level time series, not on space/time autocorrelation. The SpatRain simulator described here is constructed to generate time series of rainfall that are fully compatible with existing station-level records of daily rainfall, but yet can represent substantially different degrees of spatial autocorrelation. Calculations start from the assumed spatial characteristics of a single rainstorm pathway, with a trajectory for the core area of the highest intensity and a decrease of rainfall intensity with increasing distance from this core. The simulator can derive daily amounts of rainfall for a grid of observation points by considering the possibility of multiple storm events per day, but not exceeding the long-term maximum of observed station-level rainfall.  

Most studies of rainfall pattern focus either on the time series (degree of autocorrelation) for rainfall at a single point of observation, or on the spatial patterns of average rainfall over a monthly or yearly period. Small-range spatial variability of daily rainfall has been studied extensively in the context of design of rain-gauge networks. While the recommended density of such networks is often much higher than what exists or is feasible, the small-range variability around the existing data tends to be ignored.  Yet, if one is interested in the variability of stream and river flow at different scales, the gradual loss of synchrony in runoff-causing rainfall events is probably an important contributor to the increased evenness of river flow with increased area of consideration.  Hydrological literature reviewed by RodriguezIturbe and Rinaldo (1997) indicates that maximum daily river flow scales with area to the power 0.75, while mean annual discharge scales with area to the power 1. The difference in scaling factor can be explained by a combination of temporary water storage in river valleys and the fact that rains of high intensity rarely cover the entire basin, but are instead widely and irregularly spaced. While the temporary storage component is under the influence of land use and watershed management, the second explanation is not. It is thus important to separate the two types of explanation. An explicit representation of space-time patterns of rainfall will allow such analysis.

In situations where details of the rainfall pattern are important for crop growth and yield formation, the gradual decrease in synchrony of rain may confer advantages to households that operate fields across the village domain rather than in a single block. A quantitative approach to spatial autocorrelation of rainfall is needed to address these issues and a procedure to generate partially correlated time series for neighbouring locations is desirable for simulation studies. 

Substantial emphasis has been given to temporal autocorrelation, but if the results are subsequently assumed to hold invariantly across space, or are supposed to be derived from independent multiple domains, the scaling relations of the processes that are related to rainfall may be wrongly assessed. We thus identified a need for a tool that considers variation across both space and time at daily or event scale and developed a spatial rainfall simulator that can be used to overcome these challenges.

HOW IT WORKS
------------

Design features of SpatRain include:

[1] the program must specify degrees of spatial correlation of the simulated rainfall based on storm-level properties; and
[2] the simulated rainfall for any point in the landscape must be consistent with existing data on the frequency distribution of daily rainfall.

Station-level daily records are often the only information available on the distribution of rainfall. Such data can be represented as a series of monthly exceedance graphs, derived from the long-term station records. Between months of the year and locations we may expect differences in the intercept with the X-axis or frequency of wet days (days with a measurable amount of precipitation), the intercept with the Y-axis or maximum amount of rainfall in a single day recorded in that particular month of the year, and in the curvature of the (monotonously rising) line between these two points.

Conceptually one can imagine a procedure that reshuffles measured daily sequences of rainfall while maintaining the monthly total. It is like rearranging a jackpot, where the variability of values exposed on the window should follow our expectation. The total set of permutations of 30 sets of jackpot with 30 values is already enormous, and among these we can expect to find a substantial variation in degrees of spatial autocorrelation. By generating a sample of these reshuffling results, calculating autocorrelation and then selecting specific configurations, we would meet the key design criteria specified above. The program will, however, be rather cumbersome and time consuming if large areas are to be considered, and the selection of results that meet a specific change in spatial autocorrelation with increasing distance may require a large subset of reshuffling results. More efficient algorithms are desirable, but the jackpot analogue shows that the design rules are not mutually incompatible.  A more direct approach can be taken if we assign specific spatial properties to single storm events and then adjust the frequency of storms and the intensity of rainfall in the core area of these storms to match the existing station records. 

SpatRain starts from the spatial characteristics of a single rainstorm pathway (with a trajectory for the core area of the highest intensity and a decrease of rainfall intensity with increasing distance from this core) and can derive daily amounts of rainfall for a grid of observation points by considering the possibility of multiple storm events per day. Three parameters are used here for describing rainfall in the core area: the length and the width of the core trajectory and the rainfall depth in the core area (Imax). Two further parameters (spread and edge) describe the decrease of rainfall depth (Id) with increasing distance from the core (d). The combination of these can produce the full scale of homogenous to heterogeneous types of rain:
Id = Imax*(1-exp(-((spread/d)^edge)))

Above equation may produce a narrow-spread area of single storm events, on which its wet cells ratio relative to total area (wc) does not match the wet days fraction of that specific month (wd).   Hence, we need to allow for multiple storm events, depending on the area fraction wetted by a single event and the time fraction of rainy days at the measurement station level. For spatially independent multiple events on a single day we can derive that probability of dry days on a given month, 1-wd, should meet the probability of dry cells during single event, 1-wc, to the power of events number (N):

1-wd = (1-wc)^N

Patchy rains have less wet fraction than homogeneous rains in space.  In order to conserve each cell to having uniform chance of being hit by storms in time, patchy rains should have higher probability to occur than homogeneous rains.  Consequently, the probability of storm with N number of events (E) is defined from wet days fraction (wd) by taking wet cells fraction of N storm events (WC) into account:

E = wd/WC

Storm events will wet a number of cells, some at the core intensity and some at a lower intensity. Given a set of parameters for the storm trajectory, we can derive the frequency distribution of rain depth in wetted cells (p), in n classes. Once this is known, the frequency distribution of core intensities (F) can be derived from the observed station level rain intensities (f). 

Frequency distributions of f, p and F should have the same class number and interval order.  We use the following order to define the class boundary: 

[Rmax..Rmax*q1],[Rmax*q1.. Rmax*q2],,[Rmax*qn.. Rmin],

where Rmax is the maximum rainfall, Rmin is the minimum rainfall and n is class intervals number.  The value of q is ranging from 0 to 1 and calculated as follows:

q = exp(ln(Rmin/Rmax)/n), 0 ? q ? 1	

We first need to recognize the combinations of classes pj and Fk that are compatible with class fi:

fi ? ?(pjFk|j,k~i), Rmin ? fi ? Rmax, Rmin ? pj ? Rmax, Rmin ? Fk ? Rmax	

For the highest rainfall class there is only one combination, involving the highest class of both p and F that will yield the desired result, but for the other classes there can be several combinations of p and F that yield the same result (the tail end of a big rainfall event, a medium fraction of a medium storm or the core area of a small storm). We can approach it from the top down, but a simpler derivation starts from the observation that for all distributions f, p and F the sum equals 1. By assuming that the resultant (f) comes from the multiplication between p and F, we then get this basic equation:

?f = ?p * ?F	

From above equation, we can derive a criterion for the shape of the p distribution (that depends on assumed storm properties) that is compatible with the targeted f distribution. If at any point sum of f from frequency class 1 to i divided by sum of p from frequency class 1 to i is less than sum of F from frequency class 1 to i-1, F from frequency class i (Fi) would violate the assumption of non-negative subsequent F terms. So, a cross-over of p and f indicates incompatibility of the storm-level assumptions (that generate the p curve) with the station-level rainfall records (that generate the f curve).

HOW TO USE IT
-------------
[1] This model comes with two external text files: "rain.txt" and "stat.txt".  The file "rain.txt" contains long-term daily rainfall records from stations. Julian day (from 1 to 365) is formatted by row-order, while station or year is formatted by column order. The file "stat.txt" is grid xyz text file to show location of sample points used for simulation and analysing the results. The first column contains the values of x coordinate, the second column contains the values of y coordinate, and the third column contains the values of station id. The file "rain.txt" provided here is daily rainfall time series from the meso-scale catchments area of Sumberjaya, Lampung, Sumatra, Indonesia, obtained from 3 rainfall stations located within the catchments. One station has 21-year time series, while other two have shorter time series but are probably not significantly different in means or variance measures (Manik and Sidle, 2003).

[2] To use your own data, construct text files, using above formats, and type the names under read-input-parameters procedure:

to read-input-parameters
  set rainfall-data-file-name "your rain file name"
  set station-xyz-file-name "your sample points location file name"
end

[3] Use sliders storm-spread, storm-edge, storm-core-width and storm-core-length to adjust storm properties.

[4] Use slider class-number to define interval class for f, p and F.

[5] Use slider replicate to define sampling replicate to define p, analyse semivariance and scaling rule of maximum rainfall.

[6] Use slider sampling-distance to define distance step from starting random point in semivariance analyses.

[7] Use slider sampling-day to define number of rainfall maps used for semivariance and scaling rule analyses.

[8] Use slider simulation-duration to define duration of simulation (year).

[9] Button setup will initialise the model and calculating compatibility of your assumed storm properties.  When you got one incompatible monthly F you should readjust the storm properties using sliders storm-spread, storm-edge, storm-core-width and storm-core-length.

[10] Once you have compatible storm properties which are applicable in all months, you can run the simulations by executing button go.  It will generate daily rainfall for specified year duration, defined in step [8].

[11] Six plots are provided to capture the main outputs: saily patch rainfall from sampling points, which locations are defined by file "stat.txt", described by step [1] and [2]; annual landscape rainfall; exceedance graphs of daily simulated rainfall, compared to observed records; semivariogram, relationship between Rmax/Rmean and area.  You can report these outputs into text files, by right clicking the plots and select the menu Export.... All input settings will be recorded by the files.

[12] View is provided to visualise spatial patterns of simulated daily rainfall. The red triangles are sampling points, as defined in step [1]. You can capture this view by right clicking it and select the menu Export View.

THINGS TO NOTICE
----------------
Some caution is needed in applying the model. The current procedures are only applicable for catchments which rainfall variability is not much affected by elevation (micro- to meso-scale catchments).


THINGS TO TRY
-------------
Try to construct compatible storms with high edge, high spread and large core area. Compare the outputs.  What is your conclusion?

EXTENDING THE MODEL
-------------------
Extending the model for application in larger area should be carried out with regard to spatial trends in mean rainfall due to effects of elevation.


NETLOGO FEATURES
----------------
List related functions provided by NetLogo make random number generation procedures much easier and controllable. We use random lottery pot algorithm for generating random values. Using this approach, picked values wont be repeated.


RELATED MODELS
--------------
Rainfall simulators, crop growth models, river flow models.


CREDITS AND REFERENCES
----------------------
The SpatRain simulator is implemented using NetLogo, a java-based programmable modelling environment for simulating natural and social phenomena (Uri Wilensky, 1999). SpatRain is freely available on NetLogo website (http://ccl.northwestern.edu/netlogo/) as part of community models or on our website (http://www.worldagroforestrycentre.org/ sea/).

The development of SpatRain is funded by Bank Netherlands Partnership Programme (BNPP) and Australian Centre for International Agricultural Research (ACIAR). Initial concept and preliminary results of SpatRain was presented at a workshop of the International Union of Forest Research Organizations (IUFRO) in Kota Kinabalu, Sabah, Malaysia, July 10-12, 2004. Submission of the manuscript about the model and its application to international journal is in progress.

To refer to this model in academic publications, please use:  Suyamto, D.A., Van Noordwijk, M., Lusiana, B. 2006. SpatRain: a simulator of space/time patterns in rainfall for predicting scale dependence of variability of rainfall-related processes. World Agroforestry Centre, Southeast Asia Regional Office, Bogor, Indonesia. 

References

Manik, T.K. and Sidle, R.C.. 2003. Rainfall spatial distribution in Sumber Jaya watershed, Lampung, Indonesia. In: Post, D.A. (Ed.): Proceedings of International Congress on Modelling and Simulation MODSIM 2003, July 14-17 2003, Townsville, Australia.

Rodriguez-Iturbe, I. and Rinaldo, A..  1997.  Fractal River Basins: Chance and Self-Organization.  Cambridge University Press, New York.

Wilensky, U.. 1999. NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.  
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

raster
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -7500403 true true 0 0 300 300

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.1.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
