breed [trees tree]
breed [yields yield]

globals
[
  expectation
  realisation
  cumulative-realisation
  difference
  game-score
  cumulative-game-score
  average-game-score
  counter
  output-file-name
  extension-suggestion
  reason
  previous-expectation
]

to setup
  ca
  setup-patch
  setup-tree
  ask-output-file-name
  set cumulative-realisation 0
  set cumulative-game-score 0
  set counter 0
  set previous-expectation ""
  make-label
  ifelse extension?
  [
    set extension-suggestion max list 0 (random-normal average-yield (average-yield * cv)) * number-of-trees * harvesting-frequency
  ]
  [
    set extension-suggestion 0
  ]
end

to make-label
  file-open output-file-name
  file-print "step" + "\t" + "expectation" + "\t" + "realisation" + "\t" + "score" + "\t" + "extension?" + "\t" + "suggestion" + "\t" + "reason?"
  file-close
end

to record-results 
  file-open output-file-name
  file-print counter + "\t" + expectation + "\t" + realisation + "\t" + game-score + "\t" + extension? + "\t" + extension-suggestion + "\t" + reason
end

to play
  ifelse counter < game-replicate
  [
    set counter counter + 1
    ask-farmers-expectation
    set previous-expectation expectation
    generate-realisation
    visualize-yield
    plot-realisation
    calculate-game-score
    plot-game-score
    record-results
  ]
  [
    file-close
    user-message "[Adopt&Learn | Learning Game] Game Over!"
    stop
  ]
end

to setup-tree
  set-default-shape trees "tree"
  
  cct-trees number-of-trees
  [
    setxy -1 * max-pxcor + 2 * random max-pxcor random max-pycor
    set color scale-color green random 100 0 255
  ]
end

to setup-patch
  ask patches
  [   
    ;;quadrant 1
    if pxcor >= round(min-pxcor + (max-pxcor - min-pxcor) / 2) and pycor >= round(min-pycor + (max-pycor - min-pycor) / 2)
    [
      set pcolor scale-color yellow random-float 50 255 0
    ]
    
    ;;quadrant 2
    if pxcor < round(min-pxcor + (max-pxcor - min-pxcor) / 2) and pycor >= round(min-pycor + (max-pycor - min-pycor) / 2)
    [
      set pcolor scale-color yellow random-float 50 255 0
    ]
    
    ;;quadrant 3
    if pxcor < round(min-pxcor + (max-pxcor - min-pxcor) / 2) and pycor < round(min-pycor + (max-pycor - min-pycor) / 2)
    [
      set pcolor scale-color blue 25 255 0
    ]
    
    ;;quadrant 4
    if pxcor >= round(min-pxcor + (max-pxcor - min-pxcor) / 2) and pycor < round(min-pycor + (max-pycor - min-pycor) / 2)
    [
      set pcolor scale-color red 25 255 0
    ]      
  ]    
    
end

to ask-output-file-name
  set output-file-name user-input "[Adopt&Learn | Learning Game] Output file name: " + ".out"
end

to ask-farmers-expectation
  set expectation read-from-string user-input "[Adopt&Learn | Learning Game] How much your expectation for the next yield (yield-unit)? "
  ifelse counter > 1
  [
    ifelse previous-expectation != expectation
    [
      let reason1 "[Adopt&Learn | Learning Game] Do you have any reasons on why you changed your expectation from " + previous-expectation + " (yield-unit) to " + expectation + " (yield-unit)? "
      set reason user-input reason1
    ]
    [
      let reason2 "[Adopt&Learn | Learning Game] Do you have any reasons on why you did not change your expectation from " + expectation + " (yield-unit)? "
      set reason user-input reason2
    ]        
  ]
  [
    set reason ""
  ]
end

to generate-realisation
  set realisation max list 0 (random-normal average-yield (average-yield * cv)) * number-of-trees * harvesting-frequency
  set cumulative-realisation cumulative-realisation + realisation
  ifelse extension? and counter > 0
  [
    set extension-suggestion (cumulative-realisation / counter)
  ]
  [
    set extension-suggestion 0
  ]
end

to visualize-yield
  ask yields
  [
    die
  ]
  
  set-default-shape yields "square"
  
  cct-yields realisation
  [
    setxy (-1 + (-1 * random max-pxcor)) (-1 + (-1 * random max-pycor))
    set color blue
  ]
  
  cct-yields expectation
  [
    setxy (random max-pxcor) (-1 + (-1 * random max-pycor))
    set color red
  ]
end

to calculate-game-score
  set difference (expectation - realisation)
  
  ifelse abs realisation > 0
  [
    set game-score max list 0 round (100 * (1 - (abs difference / abs realisation)))
  ]
  [
    set game-score 0
  ]
  set cumulative-game-score cumulative-game-score + game-score
  ifelse counter > 0
  [
    set average-game-score cumulative-game-score / counter
  ]
  [
    set average-game-score 0
  ]
end

to plot-game-score
  set-current-plot "game score"
  set-current-plot-pen "current"
  plot game-score
  set-current-plot-pen "average"
  plot average-game-score
end

to plot-realisation
  set-current-plot "expectation vs realisation"
  set-current-plot-pen "realisation"
  plot realisation
  set-current-plot-pen "expectation"
  plot expectation
end

@#$#@#$#@
GRAPHICS-WINDOW
305
10
735
461
17
17
12.0
1
10
1
1
1
0
1
1
1
-17
17
-17
17

CC-WINDOW
5
533
992
628
Command Center
0

SLIDER
2
222
263
255
average-yield
average-yield
0
1
0.047935
1.0E-6
1
yield-unit/(tree.time-unit)

SLIDER
2
263
263
296
cv
cv
0
1
0.484542
1.0E-6
1
NIL

SLIDER
2
87
262
120
number-of-trees
number-of-trees
1
1200
250
1
1
trees

BUTTON
5
10
68
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
741
11
804
44
NIL
play
NIL
1
T
OBSERVER
T
NIL

MONITOR
304
470
438
519
realisation (yield-unit)
realisation
0
1

MONITOR
601
469
741
518
expectation (yield-unit)
expectation
0
1

MONITOR
447
470
594
519
expectation difference (%)
(difference / realisation) * 100
0
1

MONITOR
742
416
837
465
game score
game-score
0
1

PLOT
741
245
983
407
game score
time-unit
score
0.0
10.0
0.0
100.0
true
false
PENS
"current" 1.0 1 -10899396 true
"average" 1.0 0 -955883 true

MONITOR
870
416
983
465
average game score
average-game-score
0
1

PLOT
741
53
983
231
expectation vs realisation
time unit
yield (yield-unit)
0.0
10.0
0.0
10.0
true
false
PENS
"expectation" 1.0 0 -2674135 true
"realisation" 1.0 0 -13345367 true

TEXTBOX
3
60
153
78
filled by farmers:

TEXTBOX
4
203
154
221
filled by facilitators:

SLIDER
1
343
263
376
game-replicate
game-replicate
0
100
10
1
1
time-steps

BUTTON
74
11
191
44
clean desktop
ca
NIL
1
T
OBSERVER
T
NIL

SWITCH
2
303
263
336
extension?
extension?
0
1
-1000

MONITOR
162
411
298
460
suggestion (yield-unit)
extension-suggestion
0
1

SLIDER
2
130
262
163
harvesting-frequency
harvesting-frequency
0
14
6
1
1
time-unit/time-step

@#$#@#$#@
WHAT IS IT?
-----------
This game is aimed to measure how farmers adjust their prediction to achieve good scores, given the realisation as randomised by computer. At a game setting without suggestion, we expect to measure learning progressiveness. At a game setting with suggestion, we expect to measure extension credibility. Learning progressiveness is characterised by how much farmers trust the most recent information about actual reward earned from particular option to adjust their expectation about the benefit value of that option in the future. Learning progressiveness is defined by the slope of linear equation y=a.x, where x is relative difference between the most recent information and previous expectation ([It-1-Et-1]/Et-1), while y is relative expectation adjustment ([Et-Et-1]/Et-1) taken by farmers.  This equation suggests that not learning means a = 0. Rational learning is expected to occur when a > 0.  Farmers may also behave speculatively, increasing their expectation when the most recent information gives negative signals or the other way around (a < 0).  Within the rational learning, farmers may be overconfident of the actual trend, adjusting their expectation more than the trend (a > 1).  

Assuming that farmers have specific learning progressiveness, extension credibility is characterised by how much farmers trust the information about actual reward earned from particular option as delivered by extension agent to adjust their expectation about the benefit value of that option in the future. Extension credibility is defined by the slope of linear equation y=e.x, where x is relative difference between the information from extension agent and previous expectation ([Rt-1-Et-1]/Et-1) together with assumed learning progressiveness of farmers to the most recent information (a[It-1-Et-1]/Et-1), while y is relative expectation adjustment ([Et-Et-1]/Et-1) taken by farmers.  

HOW IT WORKS
------------
In this game, farmers are asked to predict crop yield for number of sequential steps.  Computer generates yield based on normal statistic of crop production to represent realisation of the yield. Initial prediction can be made based on farmers knowledge from their own plot, but the next predictions should be made based on their actual learning in the game. Scoring is made based on prediction accuracy using formula 100*(1-|prediction-realisation|/realisation), truncated at 0.  The game can be set up to provide suggestion for the prediction.  The suggestion is made based on realisation time-averaged. To anticipate speculative response, in this game, farmers will be asked about their reasons every time they make new prediction. Further analyses on the results should be made using appropriate statistical packages.

HOW TO USE IT
-------------
[1] Before starting the game, you have to ask the farmers to provide information about number of productive trees in their plots and harvesting frequency (e.g. 6 days a week).  

[2] Realisation on yield will be generated based on mean and its cv, provided by facilitators, using normal distribution (with truncation at zero).

[3] Switch on "extension?" will provide farmers with suggestion for the next expectation.  The suggestion is made based on time-averaged realisation.  You should start the experiment without "extension?" and repeat the experiment with "extension?".

[4] Press "setup" button. Facilitator should provide output file name to record the results.

[5] The "view" will visualize the plot and its trees in the top layer, the actual yield (realisation) in the bottom left blue box, and expected yield (expectation) in the bottom right red box.  

[6] Six monitors provide numerical information: realisation, expectation, suggestion, difference between expectation and realisation, current game score and averaged game score.  

[7] Two graphical plots provide information about previous expectation vs previous realisation and game score.

[8] The game can be started by pressing "play" button. The score of the game is made based on accuracy between farmers' expectation and realisation.

THINGS TO NOTICE
----------------
Please, avoid farmers' random response by helping them understanding the game.  Preliminary game before conducting an experiment may be useful. 

RELATED MODEL
--------------
This game is developed to measure some parameters in Adopt&Learn Model.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.1.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
