breed[stations station]
breed[rasters raster]
breed[explorers explorer]

rasters-own
[
  dem
]

stations-own
[
  temp
  elevation
  rainfall-list
  rainfall
  relative-rainfall
  distance-list  
  h-square-difference-list
  h-sum-square-difference-list
  h-sample-number-list
  h-semivariance-list    
  v-square-difference-list
  v-sum-square-difference-list
  v-sample-number-list
  v-semivariance-list
  direction-list
  elevation-difference-list
  direction-masked-distance-list
  direction-masked-direction-list
  direction-masked-elevation-difference-list
  direction-masked-pair-list
  barrier-masked-dropped-list
  barrier-masked-pair-list
  barrier-masked-elevation-difference-list
  barrier-masked-distance-list
]

globals
[
  rainfall-file-name
  station-data
  rainfall-data
  station-list
  daily-rainfall-list
  day-sequence
  day-number
  max-rainfall
  all-h-semivariance
  all-distance
  d-list
  sum-h-sv-list
  n-h-sv-list
  h-sv-list
  all-rainfall
  all-v-semivariance
  all-elevation-difference
  z-list
  sum-v-sv-list
  n-v-sv-list
  v-sv-list
  dem-file-name
  raster-data
  x-station-list
  y-station-list
  x-raster-list
  y-raster-list
  min-x-station
  min-y-station
  min-x-raster
  min-y-raster
  max-x-station
  max-y-station
  max-x-raster
  max-y-raster
]

to read-input
  user-message "Please, select the name of rainfall timeseries data file after this dialog! (*.tss)"
  set rainfall-file-name user-file  
  user-message "Please, select the name of elevation xyz data file after this dialog! (*.xyz)"
  set dem-file-name user-file
end

;;function to read data
to read-rainfall-data[file-name]
  let matrix-data[]
  if (file-name != false)
  [
    file-open file-name
    while [ not file-at-end? ]
    [ 
      set matrix-data sentence matrix-data file-read
    ]
    file-close
  ]  
  let line-data[]
  if (file-name != false)
  [
    file-open file-name
    while [ not file-at-end? ]
    [ 
      set line-data sentence line-data file-read-line
    ]
    file-close
  ]  
  let N length matrix-data
  let row length line-data  
  let col ifelse-value (row > 0) [N / row] [0]
  let i 0 
  set station-data[]
  let m n-values row [?]
  foreach  m
  [
    let j (i + col - 1)
    set station-data lput sublist matrix-data i j station-data
    set i (j + 1)
  ]  
  set rainfall-data map[remove-item 0 remove-item 1 ?] station-data
end

to read-dem-data[file-name]
  set raster-data[]
  if (file-name != false)
  [
    file-open file-name
    while [ not file-at-end? ]
    [ 
      set raster-data sentence raster-data (list (list file-read file-read file-read))
    ]
    file-close
  ]
end

to customize-coordinate
  set x-station-list[]
  set y-station-list[]
  set x-raster-list[]
  set y-raster-list[]
  foreach station-data
  [
    set x-station-list lput (first ? / 1000) x-station-list
    set y-station-list lput (item 1 ? / 1000) y-station-list
  ]
  foreach raster-data
  [
    set x-raster-list lput (first ? / 1000) x-raster-list
    set y-raster-list lput (item 1 ? / 1000) y-raster-list
  ]
  
  set min-x-station min x-station-list
  set min-y-station min y-station-list
  set max-x-station max x-station-list
  set max-y-station max y-station-list
  
  set min-x-raster min x-raster-list
  set min-y-raster min y-raster-list
  set max-x-raster max x-raster-list
  set max-y-raster max y-raster-list  
end

to create-explorers
  set-default-shape explorers "default"
  create-custom-explorers 1
  [
    ht
  ]
end

to create-rasters
  foreach raster-data
  [
    create-custom-rasters 1
    [
      setxy ((first ? / 1000) - min-x-raster + 5)  ((item 1 ? / 1000) - min-y-raster + 5)
      set dem last ?
      ht
    ]
  ]  
  ask rasters
  [
    set pcolor-of patch-here scale-color brown (dem / max values-from rasters [dem]) 0 1
  ]
end

to create-stations
  set-default-shape stations "circle"    
  foreach station-data
  [
    create-custom-stations 1
    [
      setxy ((first ? / 1000) - min-x-raster + 5) ((item 1 ? / 1000) - max-y-raster + 5)
      set rainfall-list item 0 rainfall-data
      set color blue
    ]
    set rainfall-data bf rainfall-data
  ]
  set day-number -10 ^ 31
  ask stations
  [
    set day-number max list day-number length rainfall-list
  ]
  set station-list n-values count stations [?] 
  ask patches
  [
    set pcolor white
  ]
  set all-rainfall[]
  ask stations
  [
    set all-rainfall sentence all-rainfall rainfall-list
  ]  
end

to customize-station-elevation
  ask stations
  [
    set elevation item 0 values-from rasters-here[dem]
  ]
end

to calculate-direction
  ask stations
  [
    set direction-list[]
  ]
  foreach station-list
  [
    let source ?
    without-interruption
    [
      ask station ?
      [
        foreach station-list
        [
          let target ?
                    
          set direction-list ifelse-value (source != target) 
          [
            lput (atan (xcor-of station target - xcor-of station source) (ycor-of station target - ycor-of station source)) direction-list
          ]
          [
            lput -9999 direction-list
          ]
        ]
      ]
    ]
  ]
end

to calculate-distance
  ask stations
  [
    set distance-list[]
  ]
  foreach station-list
  [
    without-interruption
    [
      ask station ?
      [
        foreach station-list
        [
          set distance-list lput (precision distance station ? 0) distance-list
        ]
      ]
    ]
  ]
end

to calculate-elevation-difference
  ask stations
  [
    set elevation-difference-list[]
  ]
  foreach station-list
  [
    let source ?
    without-interruption
    [
      ask station ?
      [
        foreach station-list
        [
          let target ?                 
          set elevation-difference-list 
          lput (precision (abs(elevation-of station target - elevation-of station source)) 0) elevation-difference-list
        ]
      ]
    ]
  ]  
end

to mask-vertical-data-to-direction
  ask stations
  [
    set direction-masked-distance-list[]
    set direction-masked-direction-list[]
    set direction-masked-elevation-difference-list[]
    set direction-masked-pair-list[]
  ]
  foreach station-list
  [
    without-interruption
    [
      ask station ?
      [
        foreach n-values length direction-list [?]
        [
          ifelse end-sampling-direction >= start-sampling-direction
          [
            if ((item ? direction-list >= start-sampling-direction and item ? direction-list <= end-sampling-direction)
            or item ? direction-list = -9999)
            [
              set direction-masked-distance-list lput item ? distance-list direction-masked-distance-list
              set direction-masked-direction-list lput item ? direction-list direction-masked-direction-list
              set direction-masked-elevation-difference-list lput item ? elevation-difference-list direction-masked-elevation-difference-list
              set direction-masked-pair-list lput ? direction-masked-pair-list
            ]
          ]
          [
            if (((item ? direction-list >= start-sampling-direction and item ? direction-list <= 360) or
            (item ? direction-list >= 0 and item ? direction-list < end-sampling-direction))
            or item ? direction-list = -9999)
            [
              set direction-masked-distance-list lput item ? distance-list direction-masked-distance-list
              set direction-masked-direction-list lput item ? direction-list direction-masked-direction-list
              set direction-masked-elevation-difference-list lput item ? elevation-difference-list direction-masked-elevation-difference-list
              set direction-masked-pair-list lput ? direction-masked-pair-list
            ]
          ]
        ]
      ]
    ]
  ]
end

to mask-vertical-data-to-barrier
  ask stations
  [
    set barrier-masked-dropped-list[]
  ]  
  without-interruption
  [
    ask stations
    [
      let num who
      ask explorers
      [
        without-interruption
        [
          foreach n-values length direction-masked-direction-list-of station num [?]
          [
            
            let drop? false
                        
            if (item ? direction-masked-direction-list-of station num != -9999)
            [
              setxy xcor-of station num ycor-of station num
              set heading item ? direction-masked-direction-list-of station num
              let travelling 0
              let travelling-distance item ? direction-masked-distance-list-of station num
              while[travelling < travelling-distance]
              [
                let lh elevation-of station num
                let mh item 0 values-from rasters-here [dem]
                let rh elevation-of station item ? direction-masked-pair-list-of station num
                let maxh max list lh rh
                
                if mh > maxh
                [
                  set drop? true
                ]
                fd 1
                set travelling travelling + 1
              ]    
            ]
            set barrier-masked-dropped-list-of station num lput drop? barrier-masked-dropped-list-of station num            
          ]
        ]
      ]
    ]
  ]  
  ask stations
  [
    set barrier-masked-pair-list[]
    set barrier-masked-elevation-difference-list[]  
    set barrier-masked-distance-list[]
  ]
  ask stations
  [
    without-interruption
    [
      foreach n-values length barrier-masked-dropped-list[?]
      [
        if not (item ? barrier-masked-dropped-list)
        [
          set barrier-masked-pair-list lput item ? direction-masked-pair-list barrier-masked-pair-list
          set barrier-masked-elevation-difference-list lput item ? direction-masked-elevation-difference-list barrier-masked-elevation-difference-list
          set barrier-masked-distance-list lput item ? direction-masked-distance-list barrier-masked-distance-list
        ]
      ]
    ]
  ]
end

to initialize
  read-input
  read-dem-data dem-file-name
  read-rainfall-data rainfall-file-name
  customize-coordinate
  
  ifelse ((max-x-raster - min-x-raster + 5) <= max-pxcor or (max-y-raster - min-y-raster + 5) <= max-pycor)
  [
    create-stations
    create-rasters
    create-explorers
    customize-station-elevation
    calculate-distance
    calculate-elevation-difference
    calculate-direction
    mask-vertical-data-to-direction
    mask-vertical-data-to-barrier
    set day-sequence 0
    ask stations
    [
      ifelse exclude-pair-with-barrier?
      [
        set v-sum-square-difference-list n-values length barrier-masked-pair-list [0]
        set v-sample-number-list n-values length barrier-masked-pair-list [0]
        set h-sum-square-difference-list n-values length barrier-masked-pair-list [0]
        set h-sample-number-list n-values length barrier-masked-pair-list [0]
      ]
      [
        set v-sum-square-difference-list n-values length direction-masked-pair-list [0]
        set v-sample-number-list n-values length direction-masked-pair-list [0]
        set h-sum-square-difference-list n-values length direction-masked-pair-list [0]
        set h-sample-number-list n-values length direction-masked-pair-list [0]
      ]
    ]
    set all-h-semivariance[]
    set all-distance[]
    set all-v-semivariance[]
    set all-elevation-difference[]
  ]
  [
    user-message "Please, adjust your view by pressing 'Edit...' button on top of it, so its max-pxcor >= " 
    + (max-x-raster - min-x-raster + 5) + " and its max-pycor >= " 
    + (max-y-raster - min-y-raster + 5) + ".  Adjust the pixel size to the new setting accordingly!"
    stop
  ]
end

to compile-data
  set daily-rainfall-list[]
  ask stations
  [
    set rainfall item day-sequence rainfall-list
  ]
  set max-rainfall max values-from stations[rainfall]
  ask stations
  [
    set relative-rainfall ifelse-value (max-rainfall > 0) [rainfall / max-rainfall] [0]
  ]
  foreach station-list
  [
    without-interruption
    [
      ask station ?
      [
        set daily-rainfall-list lput rainfall daily-rainfall-list
      ]
    ]
  ]
end

to visualise-rainfall
  ask stations
  [
    set color scale-color blue relative-rainfall 1 0
  ]
end

to calculate-h-square-difference
  ask stations
  [
    set h-square-difference-list[]
  ]  
  ask stations 
  [
    without-interruption
    [   
      ifelse exclude-pair-with-barrier?
      [
        foreach barrier-masked-pair-list
        [
          set h-square-difference-list lput ((rainfall - rainfall-of station ?) ^ 2) h-square-difference-list
        ]
      ]
      [
        foreach direction-masked-pair-list
        [
          set h-square-difference-list lput ((rainfall - rainfall-of station ?) ^ 2) h-square-difference-list
        ]
      ]
    ]
  ]
  ask stations
  [
    set h-sum-square-difference-list (map[?1 + ?2] h-sum-square-difference-list h-square-difference-list)
    set h-sample-number-list (map[?1 + 1] h-sample-number-list)
  ]  
end

to calculate-v-square-difference
  ask stations
  [
    set v-square-difference-list[]
  ]  
  ask stations 
  [
    without-interruption
    [   
      ifelse exclude-pair-with-barrier?
      [
        foreach barrier-masked-pair-list
        [
          set v-square-difference-list lput ((rainfall - rainfall-of station ?) ^ 2) v-square-difference-list
        ]
      ]
      [
        foreach direction-masked-pair-list
        [
          set v-square-difference-list lput ((rainfall - rainfall-of station ?) ^ 2) v-square-difference-list
        ]
      ]
    ]
  ]
  ask stations
  [
    set v-sum-square-difference-list (map[?1 + ?2] v-sum-square-difference-list v-square-difference-list)
    set v-sample-number-list (map[?1 + 1] v-sample-number-list)
  ]
end

to calculate-v-semivariance
  ask stations
  [
    set v-semivariance-list (map[?1 / (2 * ?2)] v-sum-square-difference-list v-sample-number-list)   
    if (length v-semivariance-list > 2)
    [
      set all-v-semivariance sentence all-v-semivariance v-semivariance-list
      
      ifelse exclude-pair-with-barrier?
      [
        set all-elevation-difference sentence all-elevation-difference barrier-masked-elevation-difference-list
      ]
      [
        set all-elevation-difference sentence all-elevation-difference direction-masked-elevation-difference-list
      ]      
    ]
  ]
  set z-list sort remove-duplicates all-elevation-difference
  set sum-v-sv-list[]
  set n-v-sv-list[]
  foreach z-list
  [
    let z ?
    let sum-v-sv 0
    let n-v-sv 0
    let i 0
    foreach all-elevation-difference
    [
      if (z = ?)
      [
        set sum-v-sv sum-v-sv + (item i all-v-semivariance)
        set n-v-sv n-v-sv + 1
      ]
      set i i + 1
    ]
    set sum-v-sv-list lput sum-v-sv sum-v-sv-list
    set n-v-sv-list lput n-v-sv n-v-sv-list
  ]  
  set v-sv-list (map[?1 / ?2] sum-v-sv-list n-v-sv-list)  
end

to calculate-h-semivariance
  ask stations
  [
    set h-semivariance-list (map[?1 / (2 * ?2)] h-sum-square-difference-list h-sample-number-list)   
    if (length h-semivariance-list > 2)
    [
      set all-h-semivariance sentence all-h-semivariance h-semivariance-list
      
      ifelse exclude-pair-with-barrier?
      [
        set all-distance sentence all-distance barrier-masked-distance-list
      ]
      [
        set all-distance sentence all-distance direction-masked-distance-list
      ]      
    ]
  ]  
  set d-list sort remove-duplicates all-distance
  set sum-h-sv-list[]
  set n-h-sv-list[]   
  foreach d-list
  [
    let d ?
    let sum-h-sv 0
    let n-h-sv 0
    let i 0
    foreach all-distance
    [
      if (d = ?)
      [
        set sum-h-sv sum-h-sv + (item i all-h-semivariance)
        set n-h-sv n-h-sv + 1
      ]
      set i i + 1
    ]
    set sum-h-sv-list lput sum-h-sv sum-h-sv-list
    set n-h-sv-list lput n-h-sv n-h-sv-list
  ]  
  set h-sv-list (map[?1 / ?2] sum-h-sv-list n-h-sv-list)
end

to plot-h-semivariance
  set-current-plot "Horizontal semivariogram"
  ifelse (length d-list >= minimum-semivariogram-data)
  [
    set-plot-x-range precision (max list 0 ((min d-list) - 1)) 0 precision ((max d-list) + 1) 0
    foreach n-values length d-list [?]
    [
      plotxy item ? d-list item ? h-sv-list
    ]
  ]
  [
    user-message "Not enough samples for horizontal semivariance analyses"
  ]
end

to plot-v-semivariance
  set-current-plot "Vertical semivariogram"
  ifelse (length z-list >= minimum-semivariogram-data)
  [
    set-plot-x-range precision (max list 0 ((min z-list) - 1)) 0 precision ((max z-list) + 1) 0
    foreach n-values length z-list [?]
    [
      plotxy item ? z-list item ? v-sv-list
    ]
  ]
  [
    user-message "Not enough samples for vertical semivariance analyses"
  ]
end

to setup
  ca
  initialize
end

to go
  ifelse day-sequence < day-number
  [
    compile-data
    visualise-rainfall
    if max daily-rainfall-list > 0
    [
      calculate-h-square-difference
      calculate-v-square-difference
    ]
    set day-sequence day-sequence + 1
  ]
  [
    calculate-h-semivariance
    calculate-v-semivariance
    plot-h-semivariance
    plot-v-semivariance
    user-message "Done!"
    stop
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
79
10
417
369
-1
-1
8.0
1
10
1
1
1
0
0
0
1
0
40
0
40

CC-WINDOW
5
383
955
478
Command Center
0

BUTTON
8
10
71
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
8
53
71
86
NIL
go
T
1
T
OBSERVER
T
NIL

PLOT
453
10
697
186
Horizontal semivariogram
horizontal lag (km)
semivariance
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 2 -13345367 true

SLIDER
451
210
944
243
start-sampling-direction
start-sampling-direction
0
360
0.0
0.5
1
degree

SLIDER
451
250
944
283
end-sampling-direction
end-sampling-direction
0
360
360.0
0.5
1
degree

PLOT
701
10
946
186
Vertical semivariogram
vertical lag (m)
semivariance
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 2 -13345367 true

SWITCH
451
290
944
323
exclude-pair-with-barrier?
exclude-pair-with-barrier?
1
1
-1000

SLIDER
451
332
943
365
minimum-semivariogram-data
minimum-semivariogram-data
5
10
5
1
1
NIL

@#$#@#$#@
WHAT IS IT?
-----------
SpatRain Tool Box is aimed to characterize spatial patterns in daily rainfall data (either observed or simulated) based on degrees of spatial correlation, either horizontally (based on distance) or vertically (based on absolute elevation difference in elevation). 


HOW IT WORKS
------------
Semivariance is used to characterize daily rainfall patterns and identify degrees of spatial correlation between station pairs, either horizontally or vertically.  Here, semivariance is calculated as half of mean square difference in daily rainfall from a number of station pairs.  For horizontal semivariance, station pairs are sampled from stations with the same horizontal lag (distance).  For vertical semivariance, station pairs are sampled from stations with the same vertical lag (absolute difference in elevation). Procedure to sample station pairs from each station is done within specified directions. A pair of stations with barrier (e.g. hill) in between can be dropped from the sampling.


HOW TO USE IT
-------------
[1] Prepare elevation data in text tab delimited file in column-wise format, where the first and the second columns are x and y of UTM coordinates in bottom-top projection, and z is elevation (m a.s.l). Example: elevation data of three patches.

423151	9427920	1028.47
424151	9427920	851.412
425151	9427920	825.447

[2] Prepare rainfall data in text tab delimited file in column-wise format, where the first and the second columns are x and y of UTM coordinates of the locations of rainfall stations, and the next columns are daily rainfall data. All stations must have rainfall data on given day. The program does not handle missing data.  Example: 3-day rainfall data from three stations.

449706	9440119	9	24	13
446696	9437060	14	26	22
443359	9435662	28	12	26

[3] Locations of all stations must be inside the boundary of elevation map!

[4] We provide you with readily input data files from Sumberjaya, Lampung, Sumatra, Indonesia.  Elevation data file: dem.xyz.  Rainfall data files: feb.tss, mar.tss, apr.tss, may.tss, jun.tss, jul.tss, aug.tss, sep.tss, oct.tss, nov.tss, and dec.tss.  

[5] Run SpatRain Tool Box using NetLogo version 3.1.2 or above. NetLogo is freely downloadable from http://ccl.northwestern.edu/netlogo/.

[6] First of all, you have to make the sampling setting.  Sampling direction is determined by sliders: start-sampling-direction and end-sampling-direction.  For example: sampling in all directions is determined by 0-360 degree, north-south direction is determined by 337.5-22.5 degree or 157.5-202.5 degree, northeast-southwest direction is determined by 22.5-67.5 degree or 202.5-247.5 degree, east-west direction is determined by 67.5-112.5 degree or 247.5-292.5 degree, and southeast-northwest direction is determined by 112.5-157.5 degree or 292.5-337.5 degree.

[7] You have option to exclude a pair of stations from the sampling with barrier in between (e.g. due to hill) by switch on exclude-pair-with-barrier?.

[8] Slider minimum-semivariogram-data determines the minimum data considered for constructing semivariograms.

[9] Now, you can start setting up the analyses by executing the setup button.  First, you will be asked to select the rainfall input data file name: Please, select the name of rainfall data file after this dialog! and then the elevation data file name: Please, select the name of elevation data file after this dialog!.

[10] If you got error-message: Please, adjust your view by pressing 'Edit...' button on top of it, so that its max-pxcor >= [value] and its max-pycor >= [value].  Adjust the pixel size to the new setting accordingly!", it means that current setting of the View does not match with your data.  Just follow the instruction in the message!

[11] In the View you should see blue circles representing stations on top of the elevation map.  Darker the colour of the elevation map, lower its elevation.

[12] Now, you can start the analyses by executing go button. You should see in the view that the colours of the stations change according to rainfall on given day.  Darker the colour, higher the rainfall.

[13] When its done, you should see the results from two plots provided: Horizontal semivariogram and Vertical semivariogram.  You can save the results into *.csv files by right-clicking inside the plots, and select Export....  

THINGS TO NOTICE
----------------
If you want to observe daily rainfall carefully from the view, you can adjust the speed from slider provided on top of the view.


THINGS TO TRY
-------------
Try with data we provided for you or with your own data.  From the results, you should analyse it further using any statistical packages (e.g. SigmaPlot) to characterize the semivariograms.


EXTENDING THE MODEL
-------------------
Semivariance is only one way to characterise spatial patterns.  Other options are fractal analyses.


NETLOGO FEATURES
----------------
NetLogo speaks like human being! That ease us to use it for this purpose.


RELATED MODELS
--------------
SpatRain: a simulator of space/time patterns in rainfall for predicting scale dependence of variability of rainfall-related processes (developed by Ecological Modelling and Database Unit, World Agroforestry Center, Southeast Asia Regional Office, Bogor, Indonesia).


CREDITS AND REFERENCES
----------------------
Developed by: Ecological Modelling and Database Unit, World Agroforestry Center, Southeast Asia Regional Office, Bogor, Indonesia.  Correspondence: d.suyamto@cgiar.org.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.1.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
